@@ -3,9 +3,10 @@ import io
 import os
 import os.path
 import subprocess
+
+from setuptools.command.build_ext import build_ext as _build_ext
 from distutils.core import Extension
 from distutils.errors import CompileError, DistutilsOptionError
-from distutils.command.build_ext import build_ext as _build_ext
 from versioninfo import get_base_dir
 
 try:
